#! /usr/bin/env python
#
#    pwconf.py - configuration settings for pywrite, an enhanced local write
#    Copyright (C) 2002  Michael Urman
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import os, sys

def subdir(user=''):
    """subdir(user='') -> string

    Return the base directory for a user's PyWrite files"""

    return os.path.expanduser(os.path.join('~' + user, '.pywrite'))

def socket(user=''):
    """socket(user='') -> string

    Return a user's pywrite socket"""

    return os.path.join(subdir(user), 'pywrite_sock')

def logdir(user=''):
    """logdir(user='') -> string

    Return a user's logging directory"""

    return os.path.join(subdir(user), 'logs')

def checkdirs():
    """checkdirs() -> int

    Verify existence or create PyWrite directories.  Return false if a
    non-directory exists with desired name."""

    if not os.path.exists(subdir()):
        os.mkdir(subdir(), 0711)
        os.mkdir(logdir(), 0700)
    elif not os.path.isdir(subdir()):
        print >> sys.stderr, "Desired PyWrite directory %s exists but is not a directory.  Exiting." % subdir()
        return 0

    homedir = os.path.expanduser('~')
    mode = os.stat(homedir)[0]
    modestring = ('%04o' % mode)[-4:]

    if not (os.stat(homedir)[0] & 011) == 011:
        print >> sys.stderr, "Warning: Need to change access mode on %s to allow PyWrite to work." % homedir
        print >> sys.stderr, "         Change back later with 'chmod %s %s' if desired." % (modestring, homedir)
        try:
            ok = raw_input('OK to change? Enter one of Yes, No, or Control-C: ')
            if ok[0] not in 'Yy':
                raise EOFError
        except (EOFError, KeyboardInterrupt):
            print >> sys.stderr, "\nPermissions on %s unchanged.  Exiting." % homedir
            return 0
        mode = mode | 011
        os.chmod(homedir, mode)
        modestring = ('%04o' % mode)[-4:]
        print >> sys.stderr, "\nPermissions changed to %s.  Starting Server." % modestring

    return 1

